@@ -17,7 +17,7 @@ type cycloneDXReporter struct {
 func (r *cycloneDXReporter) PrintResult(vulnerabilityResults *models.VulnerabilityResults) error {
 	errs := output.PrintCycloneDXResults(vulnerabilityResults, r.version, r.writer)
 	if errs != nil {
-		for _, err := range strings.Split(errs.Error(), "\n") {
+		for err := range strings.SplitSeq(errs.Error(), "\n") {
 			cmdlogger.Warnf("Failed to parse package URL: %v", err)
 		}
 	}
